class Shihiteo():
	def __init__(self):
		self = self.self
	def ghoul():
		return('1000-7')
	def letmedie():
		k = 1000
		v = ['Я','','Гуль!','','','let','me','die']
		while k > 0:
			k-=7
			if k < 0:
				pass
			else:
				v.append(k)
		return(v)

		